@@ -16,7 +16,7 @@ sub emit {
 
   if (my $s = $self->{events}{$name}) {
     warn "-- Emit $name in @{[blessed($self)]} (@{[scalar(@$s)]})\n" if DEBUG;
-    for my $cb (@$s) { $self->$cb(@_) }
+    $self->$_(@_) for @$s;
   }
   elsif (DEBUG) { warn "-- Emit $name in @{[blessed($self)]} (0)\n" }
 
